# Script saved from Dejal Simon 2.4.1a2 <http://www.dejal.com/simon/>
# 
# Saved by Wade Maxfield on 06/06/08 5:50:22 PM
# 
# Script is for Ruby: /usr/bin/ruby

# *** INSTRUCTIONS: ***
# 
# Parses the results of the test for name/value pairs and then notifies 
# by email if any of the values differ by more than the 
# warningThreshold since the last check. Use a negative number as the 
# warningThreshold if you want to check for values that decrease over 
# time. For use with the MySQL service, and queries like SHOW global 
# status WHERE (variable_name LIKE "Qcache%") 
# 
# Requires Simon 2.4.1 or newer. 
# 
# As an example: Set up a Test and Notifier to check if MySQL has 
# restarted. For this test we will check the value of the Uptime status 
# variable in MySQL. Since it shows the current uptime in seconds, it 
# should not decrease, if it does send a notification email since MySQL 
# must have restarted. 
# 
# In a MySQL Service test set the Server, Port, Database and Security 
# values to whatever are required to connect to your MySQL server, then 
# set the Query to SHOW global status WHERE (variable_name="Uptime"). 
# Add Notifiers for Change and Failure, and set both to use the 
# Notifier you have setup with this script 
# 
# In the Notifier, set the mail options as needed. Set the 
# warningThreshold to -1, then if the Uptime variable is ever lower 
# that the previous check, MySQL must have restarted, so this script 
# will send the notification email. 
# 
# Comments can be directed to http://www.hotblack.co.nz/ 

# *** CUSTOM VARIABLES: ***
# 
# counterfile: /tmp/mysql-{TestURL}-counters
# mailServer: mail.domain.com
# sendFrom: user@domain.com
# sendTo: user@domain.com
# simonHostName: simon.domain.com
# subject: Simon says MySQL changed 
# warningThreshold: 1

# *** CUSTOM RESULTS: ***
# 
# 0: Success

# *** SCRIPT: ***

require 'net/smtp'

current = "{TestChangeText}"
threshold = "{warningThreshold}".to_i

$cacheFile = "{counterfile}"
$currentMap = Hash.new
$cacheMap = Hash.new
issueCount = 0
message = ""


def loadCacheMap
	if File.exists?($cacheFile)
		File.open($cacheFile, 'r') do |f|
			f.each do |item|
				temp = item.chomp.split(/ : /)
				if temp.size == 2
					$cacheMap[temp[0]]=temp[1]
				end
			end
		end
	end
end


def writeCacheMap
	File.open($cacheFile, 'w') do |f|
		$currentMap.keys.each do |item|
			f.puts "#{item} : #{$currentMap[item]}"
		end
	end
end


def send_email(from, to, subject, message)
 msg = <<END_OF_MESSAGE
From: #{from}
To: #{to}
Subject: {subject}

#{message}
END_OF_MESSAGE

 Net::SMTP.start('{mailServer}', 25) do |smtp|
   smtp.send_message msg, from, to
 end
end


loadCacheMap


temp_stats = current.chomp.split(/\n/)
temp_stats.each do |item|
	temp = item.chomp.split(/\t/)
	if temp.size == 2
		if temp[0] != "Variable_name"
			$currentMap[temp[0]]=temp[1]
		end
	end
end


writeCacheMap


$currentMap.keys.each do |item|
	if threshold < 0
		temp = ($cacheMap[item].to_i - $currentMap[item].to_i)
	else
		temp = ($currentMap[item].to_i - $cacheMap[item].to_i)
	end
	if temp >= threshold.abs
		issueCount+=1
		message+="
current #{item} value is #{$currentMap[item]}
previous #{item} value was #{$cacheMap[item]}
"
	end
end


if issueCount > 0
 message = "
{TestName} <{TestURL}> changed at {TestLastChangeTime} on {TestLastChangeDate}.  Please investigate and remedy if needed.
" + message + "
Thank you for your attention.

This notification was sent automatically from {simonHostName}
"
 send_email("{sendFrom}", "{sendTo}", "{subject}", message)
end
